jQuery(document).ready(function($){
	// Change Iframe on Menu Click
	$('#trm-links-list .menu').on('click', 'a[data-attr]', function(){
		var attr   = $(this).attr('data-attr');
		var $frame = $('#trm-links-list main div.'+attr);
		
		// Remove all active classes and hide active frame
		$('#trm-links-list .menu a, #trm-links-list main div').removeClass('active');

		// Set this menu item to active
		$(this).addClass('active');

		// Set this frame to active
		$frame.addClass('active'); 

		// Actually Load in the iframe
		if( $frame.find('iframe').attr('src') == null ){
			$frame.find('iframe').attr('src', $frame.find('iframe').attr('data-src') );
		}
	});
	
	// Allow menu to collapse for more space
	$('#trm-links-list .menu').on('click', '.collapse', function(){
		$('.menu a span').hide();
		$(this).removeClass('collapse').addClass('grow');
		$(this).find('svg').removeClass('fa-chevron-circle-left').addClass('fa-chevron-circle-right');
		$('.menu').css({'width':60}).addClass('increase');
		$('main').css({'width':'calc( 100% - 60px )'});
	});
	
	// Undo the above collapse
	$('.menu').on('click', '.grow', function(){
		$('.menu a span').show();
		$(this).removeClass('grow').addClass('collapse');
		$(this).find('svg').removeClass('fa-chevron-circle-right').addClass('fa-chevron-circle-left');
		$('.menu').css({'width':230}).removeClass('increase');
		$('main').css({'width':'calc( 100% - 230px )'});
	});

	// Show Add New Link Form
	$('.menu .add').on('click', function(){
		$('#add-new').fadeIn();
	});

	// Submit new link via Ajax
	$('#add-new-link').on( 'submit', function(e){
		e.preventDefault();

		// Change to spinner
		$('#add-new-link').addClass('trm-links-reloading');

		var data = {
			'action':    'add_new_important_link',
			'url':       $('input[name="url"]').val(),
			'login_url': $('input[name="login_url"]').val(),
			'label':     $('input[name="label"]').val(),
			'add_new_account': $('input[name="add_new_account"]').val(),
		};

		$.post(ajaxurl, data, function(response){
			// Hide form, remove spinner
			$('#add-new').fadeOut();
			$('#add-new-link').removeClass('trm-links-reloading');

			// Reset the form
			$('input[name="url"]').val('');
			$('input[name="login_url"]').val('');
			$('input[name="label"]').val('');

			if( response.status == 200 ){
				// Success! Add the link to the menu and frame to container
				var numLinks = $('#trm-links-list .menu a').length - 2;
				var active = numLinks == 0 ? 'active' : '';
				if( numLinks == 0 ) $('.no-links').remove();
				$('<a class="'+ active +'" data-id="'+ response.newLink.id +'" href="#" data-attr="link-'+ numLinks +'"><svg class="" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M10 13a5 5 0 0 0 7.54.54l3-3a5 5 0 0 0-7.07-7.07l-1.72 1.71"></path><path d="M14 11a5 5 0 0 0-7.54-.54l-3 3a5 5 0 0 0 7.07 7.07l1.71-1.71"></path></svg> <span>'+response.newLink.label.replace('\\', '')+'</span></a>').insertBefore('.menu .collapse');
				
				var loginLink = response.newLink.login_url ? '<a href="'+ response.newLink.login_url +'" target="_blank">Login</a>' : '';
				$('<div data-id="'+ response.newLink.id +'" class="link-'+ numLinks +' '+ active +'"><iframe src="'+ response.newLink.url.replace('http://', 'https://') +'"></iframe><nav class="lower-menu">'+ loginLink +'<a href="'+ response.newLink.url +'" target="_blank">Open in a New Tab</a><a href="#" class="remove" data-id="'+ response.newLink.id +'" title="Remove This Link"><svg class="" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round"><path d="M14 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8z"></path><polyline points="14 2 14 8 20 8"></polyline><line x1="9" y1="15" x2="15" y2="15"></line></svg></a></nav></div>').appendTo('#trm-links-list main');
			} else if( response.status == 400 || response.status == 403 ){
				classes = 'error';
				alert( response.message );
			}
		}, 'json');

		return false;
	});

	$('#trm-links-list main').on( 'click', '.lower-menu .remove', function(e){
		if( confirm( 'Are you sure you want to remove this link?' ) ){
			e.preventDefault();

			var id = $(this).attr('data-id');

			var data = {
				'action': 'remove_important_link',
				'id': id,
			};

			$.post(ajaxurl, data, function(response){
				if( response.status == 200 ){
					$('#trm-links-list .menu a[data-id="'+ response.id +'"]').fadeOut(function(){
						$.when( $(this).remove() )
						.then(function(){
							var index = 0;
							$('#trm-links-list .menu a[data-id]').each(function(){
								$(this).attr('data-attr', 'link-'+index);

								index++;
							});

							$('#trm-links-list .menu a[data-id]').last().addClass('active');
						});
					});
					$('#trm-links-list main div[data-id="'+ response.id +'"]').fadeOut(function(){
						$.when( $(this).remove() )
						.then( function(){
							var dindex = 0;
							$('#trm-links-list main > div').each(function(){
								$(this).attr('class','link-'+dindex);

								dindex++;
							});

							var $frame = $('#trm-links-list main div[data-id]').last();

							if( $frame != null && $frame.length > 0 ){
								$frame.addClass('active');
								
								$frame.find('iframe').attr('src', $frame.attr('data-src') );
								$frame.find('iframe').attr('data-src', '');
							}
						});
					});

				} else if( response.status == 400 || response.status == 403 ){
					alert( response.message );
				}
			}, 'json');
		}
	});
});